#  tests for gtk4-4.2.1-h12d828d_1 (this is a generated file);
print('===== testing package: gtk4-4.2.1-h12d828d_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import gi
gi.require_version('Gdk', '4.0')
gi.require_version('Gsk', '4.0')
gi.require_version('Gtk', '4.0')
from gi.repository import Gdk, Gsk, Gtk

Gtk.disable_setlocale()
#  --- run_test.py (end) ---

print('===== gtk4-4.2.1-h12d828d_1 OK =====');
