"${PREFIX}/bin/glib-compile-schemas" "${PREFIX}/share/glib-2.0/schemas"
"${PREFIX}/bin/gtk4-update-icon-cache" -f -t "${PREFIX}/share/icons/hicolor"
"${PREFIX}/bin/gio-querymodules" "${PREFIX}/lib/gtk-4.0/4.0.0/printbackends"
