



gtk4-encode-symbolic-svg --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
gtk4-update-icon-cache --help
IF %ERRORLEVEL% NEQ 0 exit /B 1
where gtk4-builder-tool
IF %ERRORLEVEL% NEQ 0 exit /B 1
where gtk4-query-settings
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-4.0\\gdk\\gdk.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-4.0\\gsk\\gsk.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\include\\gtk-4.0\\gtk\\gtk.h exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gtk4.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\\Library\\lib\\pkgconfig\\gtk4-win32.pc exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\Library\lib\girepository-1.0\Gdk-4.0.typelib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\Library\lib\girepository-1.0\Gsk-4.0.typelib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
if not exist %PREFIX%\Library\lib\girepository-1.0\Gtk-4.0.typelib exit 1
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
